@@ -238,12 +238,12 @@ impl History {
         &self,
         cmd: &str,
         num: i16,
-        fuzzy: bool,
+        fuzzy: i16,
         result_sort: &ResultSort,
     ) -> Vec<Command> {
         let mut like_query = "%".to_string();
 
-        if fuzzy {
+        if fuzzy > 0 {
             like_query.push_str(&cmd.split("").collect::<Vec<&str>>().join("%"));
         } else {
             like_query.push_str(cmd);
@@ -282,7 +282,11 @@ impl History {
                 let lowercase_cmd = cmd.to_lowercase();
 
                 let bounds = match fuzzy {
-                    true => {
+                    0 => lowercase_text
+                        .match_indices(&lowercase_cmd)
+                        .map(|(index, _)| (index, index + cmd.len()))
+                        .collect::<Vec<_>>(),
+                    _ => {
                         let mut search_iter = lowercase_cmd.chars().peekable();
                         let mut matches = lowercase_text
                             .match_indices(|c| {
@@ -303,10 +307,6 @@ impl History {
 
                         vec![(start, end)]
                     }
-                    false => lowercase_text
-                        .match_indices(&lowercase_cmd)
-                        .map(|(index, _)| (index, index + cmd.len()))
-                        .collect::<Vec<_>>(),
                 };
 
                 Command {
@@ -391,24 +391,45 @@ impl History {
             }));
         }
 
-        if fuzzy {
+        if fuzzy > 0 {
             names = names
                 .into_iter()
                 .sorted_by(|a, b| {
-                    // results are already sorted by rank, but with fuzzy mode we
-                    // need to prioritize shorter matches as well, and can only do
-                    // that at runtime. Each match's rank is weighted by the
-                    // inverse of its length (relative to both matches) to give
-                    // short but lower-ranked matches a chance to beat higher-
-                    // ranked but longer matches.
+                    // Fuzzy matches impose new ordering criteria on top of the
+                    // natural rank-based sorting: at the most basic level,
+                    // shorter and earlier matches are more likely to be
+                    // desired than longer or later matches -- even if they are
+                    // ranked a little lower.
+                    //
+                    // Each match is weighted by the inverse of its length plus
+                    // start position, relative to the total length + start of
+                    // both matches added together. This yields two complements
+                    // which always add up to 1 (e.g. 0.6 vs 0.4). If both
+                    // matches have the same length and start position, or if
+                    // those balance out exactly, the resulting weights will
+                    // both equal 0.5.
+                    //
+                    // The weights are multiplied by the configurable fuzzy
+                    // factor before being added to each result's original
+                    // rank. Factors > 1 are a "thumb on the scale" increasing
+                    // the likelihood of the weight flipping the outcome for
+                    // the originally lower-ranked result.
 
-                    let a_len = a.match_bounds[0].1 - a.match_bounds[0].0;
-                    let b_len = b.match_bounds[0].1 - b.match_bounds[0].0;
-                    let a_mod = 1.0 - a_len as f64 / (a_len + b_len) as f64;
-                    let b_mod = 1.0 - b_len as f64 / (a_len + b_len) as f64;
+                    let a_start = a.match_bounds[0].0;
+                    let b_start = b.match_bounds[0].0;
+                    let a_len = a.match_bounds[0].1 - a_start;
+                    let b_len = b.match_bounds[0].1 - b_start;
 
-                    PartialOrd::partial_cmp(&(b.rank + b_mod), &(a.rank + a_mod))
-                        .unwrap_or(Ordering::Equal)
+                    let a_mod =
+                        1.0 - (a_start + a_len) as f64 / (a_start + b_start + a_len + b_len) as f64;
+                    let b_mod =
+                        1.0 - (b_start + b_len) as f64 / (a_start + b_start + a_len + b_len) as f64;
+
+                    PartialOrd::partial_cmp(
+                        &(b.rank + b_mod * fuzzy as f64),
+                        &(a.rank + a_mod * fuzzy as f64),
+                    )
+                    .unwrap_or(Ordering::Equal)
                 })
                 .collect()
         }
